@@ -59,9 +59,9 @@ pref("general.warnOnAboutConfig", true);
 pref("browser.bookmarks.max_backups",       5);
 
 pref("browser.cache.disk.enable",           true);
-//@line 63 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 63 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 pref("browser.cache.disk.capacity",         51200);
-//@line 67 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 67 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 pref("browser.cache.memory.enable",         true);
 //pref("browser.cache.memory.capacity",     -1);
 // -1 = determine dynamically, 0 = none, n = memory capacity in kilobytes
@@ -70,7 +70,7 @@ pref("browser.cache.disk_cache_ssl",        false);
 pref("browser.cache.check_doc_frequency",   3);
 
 pref("browser.cache.offline.enable",           true);
-//@line 76 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 76 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 // offline cache capacity in kilobytes
 pref("browser.cache.offline.capacity",         512000);
 
@@ -81,7 +81,7 @@ pref("offline-apps.quota.max",        204800);
 // the user should be warned if offline app disk usage exceeds this amount
 // (in kilobytes)
 pref("offline-apps.quota.warn",        51200);
-//@line 92 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 92 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 
 // Fastback caching - if this pref is negative, then we calculate the number
 // of content viewers to cache based on the amount of available memory.
@@ -145,11 +145,11 @@ pref("media.enforce_same_site_origin", false);
 // Media cache size in kilobytes
 pref("media.cache_size", 51200);
 
-//@line 156 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 156 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 pref("media.ogg.enabled", true);
-//@line 159 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 159 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 pref("media.wave.enabled", true);
-//@line 161 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 161 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 
 // Whether to autostart a media element with an |autoplay| attribute
 pref("media.autoplay.enabled", true);
@@ -167,7 +167,7 @@ pref("accessibility.warn_on_browsewithcaret", true);
 
 pref("accessibility.browsewithcaret_shortcut.enabled", true);
 
-//@line 179 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 179 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -180,7 +180,7 @@ pref("accessibility.tabfocus_applies_to_xul", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 195 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 195 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -524,9 +524,9 @@ pref("dom.storage.enabled", true);
 pref("dom.storage.default_quota",      5120);
 
 // Parsing perf prefs. For now just mimic what the old code did.
-//@line 539 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 539 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 541 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 541 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -575,7 +575,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 592 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 592 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -732,6 +732,8 @@ pref("network.IDN.whitelist.tw", true);
 pref("network.IDN.whitelist.vn", true);
 
 // IDN ccTLDs
+// ae, UAE, .<Emarat>
+pref("network.IDN.whitelist.xn--mgbaam7a8h", true); 
 // sa, Saudi Arabia, .<al-Saudiah>
 pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true); 
 // ru, Russian Federation, .<RF>
@@ -825,7 +827,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 847 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 849 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -884,6 +886,9 @@ pref("network.proxy.autoconfig_url", "");
 pref("network.proxy.autoconfig_retry_interval_min", 5);    // 5 seconds
 pref("network.proxy.autoconfig_retry_interval_max", 300);  // 5 minutes
 
+pref("network.buffer.cache.count", 24);
+pref("network.buffer.cache.size",  4096);
+
 pref("converter.html2txt.structs",          true); // Output structured phrases (strong, em, code, sub, sup, b, i, u)
 pref("converter.html2txt.header_strategy",  1); // 0 = no indention; 1 = indention, increased with header level; 2 = numbering and slight indention
 
@@ -1206,9 +1211,7 @@ pref("dom.max_script_run_time", 10);
 
 // How long a plugin is allowed to process a synchronous IPC message
 // before we consider it "hung".
-//
-//  NB: chosen to match dom.max_script_run_time by default
-pref("dom.ipc.plugins.timeoutSecs", 10);
+pref("dom.ipc.plugins.timeoutSecs", 45);
 
 pref("svg.enabled", true);
 pref("svg.smil.enabled", false);
@@ -1245,15 +1248,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1664 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 1667 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 
-//@line 2088 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 2091 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 
-//@line 2291 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 2294 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 
-//@line 2387 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 2390 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 
-//@line 2390 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 2393 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1523,15 +1526,15 @@ pref("ui.panel.default_level_parent", true);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 2662 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 2665 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 
-//@line 2730 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 2733 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 
-//@line 2756 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 2759 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 
-//@line 2776 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 2779 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 
-//@line 2784 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 2787 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1568,9 +1571,9 @@ pref("image.cache.timeweight", 500);
 // The default Accept header sent for images loaded over HTTP(S)
 pref("image.http.accept", "image/png,image/*;q=0.8,*/*;q=0.5");
 
-//@line 2826 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 2829 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 
-//@line 2831 "/icecat-3.6.4/modules/libpref/src/init/all.js"
+//@line 2834 "/icecat-3.6.7/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
